# Changelog

## [0.2.0](https://github.com/a2anet/a2a-utils/compare/a2a-utils-python-v0.1.0...a2a-utils-python-v0.2.0) (2026-03-18)


### Features

* initialize project from python-javascript-template ([2991fed](https://github.com/a2anet/a2a-utils/commit/2991fed3124516fb34eebecc619549fe64f13a2e))
* **python:** add A2ASession, AgentManager, TextArtifacts, DataArtifacts, FileStore, JSONTaskStore, and LLM-friendly A2A types ([96a930b](https://github.com/a2anet/a2a-utils/commit/96a930ba35eabef9e6ddf4aa3a18a7f2f30d2b2e))
* **python:** add py.typed marker for PEP 561 compliance ([d1a910c](https://github.com/a2anet/a2a-utils/commit/d1a910c43fe6254475f4434ed441e3a8ccfd792c))
